API Reference
=============

.. contents:: :local:


``km3flux.flux``
-----------------

.. automodule:: km3flux.flux
  :no-members:
  :no-inherited-members:

.. currentmodule:: km3flux.flux

.. autosummary::
  :toctree: api

  BaseFlux
  AllFlavorFlux
  Honda2015
  HondaSarcevic
  PowerlawFlux
  DarkMatterFlux


``km3flux.weights``
----------------

.. automodule:: km3flux.weights
  :no-members:
  :no-inherited-members:

.. currentmodule:: km3flux.weights

.. autosummary::
  :toctree: api

  nu_wgt
  atmu_wgt
  make_weights
  strange_flavor_to_mupage
  add_flavor
  add_weights_and_fluxes


``km3flux.aeff``
----------------

.. automodule:: km3flux.aeff
  :no-members:
  :no-inherited-members:

.. currentmodule:: km3flux.aeff

.. autosummary::
  :toctree: api


  integrated_energy
  integrated_zenith
  aeff_scale_factor
